summaryrefslogtreecommitdiff
path: root/Xi/selectev.c
diff options
context:
space:
mode:
authorPeter Hutterer <peter.hutterer@who-t.net>2009-03-06 22:27:54 +1000
committerPeter Hutterer <peter.hutterer@who-t.net>2009-03-20 15:17:54 +1000
commit43e48900fccd245e98d6d697e4cdbb6fa866a0dd (patch)
tree27b5c2b09717a6ef0015303183e7ee250584c7d7 /Xi/selectev.c
parent70896f6127e2c12c13479a027fdd6e67853d1f8b (diff)
dix: Force deviced ids of 2 and higher for actual devices.
0 is now reserved for the "AllDevices" virtual device. 1 is now reserved for the "AllMasterDevices" virtual device. This also means that wherever we passed in (mskidx = 0), we now need to pass in the deviceid.
Diffstat (limited to 'Xi/selectev.c')
-rw-r--r--Xi/selectev.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/Xi/selectev.c b/Xi/selectev.c
index b785a8e45..45bf68b3b 100644
--- a/Xi/selectev.c
+++ b/Xi/selectev.c
@@ -58,6 +58,7 @@ SOFTWARE.
#include "inputstr.h" /* DeviceIntPtr */
#include "windowstr.h" /* window structure */
#include <X11/extensions/XI.h>
+#include <X11/extensions/XI2.h>
#include <X11/extensions/XIproto.h>
#include "exevents.h"
#include "exglobals.h"
@@ -103,10 +104,9 @@ HandleDevicePresenceMask(ClientPtr client, WindowPtr win,
if (mask == 0)
return Success;
/* We always only use mksidx = MAXDEVICES for events not bound to
* devices */
-
- if (AddExtensionClient (win, client, mask, MAXDEVICES) != Success)
+ if (AddExtensionClient (win, client, mask, AllDevices) != Success)
return BadAlloc;
RecalculateDeviceDeliverableEvents(win);
@@ -103,10 +104,9 @@ HandleDevicePresenceMask(ClientPtr client, WindowPtr win,
if (mask == 0)
return Success;
- /* We always only use mksidx = MAXDEVICES for events not bound to
+ /* We always only use mksidx = AllDevices for events not bound to
* devices */